@@ -15,7 +15,7 @@ Version 0.10
 
 =cut
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ use POSIX qw(floor ceil);
 # Fields are NOT used internally for now, so this is just a declaration
 use fields qw(
 	data count
-	linear_width base logbase floor linear_thresh logfloor
+	linear_width base logbase floor linear_thresh only_linear logfloor
 	cache
 );
 
@@ -168,6 +168,14 @@ However, user may want to specify both in some cases.
 B<NOTE> Actual value may be less (by no more than a factor of C<base>)
 so that borders of linear and logarithmic bins fit nicely.
 
+=item * only_linear = 1 (B<EXPERIMENTAL>) -
+throw away log approximation and become a discrete statistics
+class with fixed precision.
+C<linear_width> must be given in this case.
+
+B<NOTE> This obviously kills memory efficiency, unless one knows beforehand
+that all values come from a finite pool.
+
 =item * data - hashref with C<{ value => weight }> for initializing data.
 Used for cloning.
 See C<add_data_hash()>.
@@ -180,12 +188,21 @@ DEPRECATED, C<linear_width> and C<linear_thresh> override this if given.
 
 =cut
 
-my @new_keys = qw( base linear_thresh linear_width zero_thresh data );
+my @new_keys = qw( base linear_width linear_thresh data zero_thresh only_linear );
 	# TODO Throw if extra options given?
+	# TODO Check args better
 sub new {
 	my $class = shift;
 	my %opt = @_;
 
+	# First, check for only_linear option
+	if ($opt{only_linear}) {
+		$opt{linear_width}
+			or croak "only_linear option given, but no linear width";
+		$opt{only_linear} = $opt{linear_width};
+		delete $opt{$_} for qw(linear_width base linear_thresh zero_thresh);
+	};
+
 	# base for logarithmic bins, sane default: +-1%, exact decimal powers
 	# UGLY HACK number->string->number to avoid
 	#     future serialization inconsistencies
@@ -233,6 +250,12 @@ sub new {
 		$self->{linear_width} = (2 * $self->{linear_thresh} / $n_linear);
 	};
 
+	if ($opt{only_linear}) {
+		$self->{linear_width} = $opt{only_linear};
+		$self->{linear_thresh} = $INF;
+		$self->{only_linear} = 1;
+	};
+
 	$self->clear;
 	if ($opt{data}) {
 		$self->add_data_hash($opt{data});
@@ -406,6 +429,8 @@ sub variance {
 
 =head2 std_dev
 
+=head2 stdev
+
 Return standard deviation, i.e. square root of variance.
 
 Bessel's correction (division by n-1 instead of n) is used by default.
@@ -650,6 +675,47 @@ sub std_moment {
 		/ ( $dev**$n * $self->{count} );
 };
 
+=head2 abs_moment( $power, [$offset] )
+
+Return $n-th moment of absolute value, that is, C<E(|x - offset|^$n)>.
+
+Default value for offset if E(x).
+Power may be fractional.
+
+B<NOTE> Experimental. Not present in Statistics::Descriptive::Full.
+
+=cut
+
+sub abs_moment {
+	my ($self, $power, $offset) = @_;
+
+	$offset = $self->mean unless defined $offset;
+	return $self->sum_of(sub{ return abs($_[0] - $offset) ** $power })
+		 / $self->{count};
+};
+
+=head2 std_abs_moment( $power, [$offset] )
+
+Returns standardized absolute moment - like above, but scaled
+down by a factor of to standard deviation to n-th power.
+
+That is, C<E(|x - offset|^$n) / E(|x - offset|^2)^($n/2)>
+
+Default value for offset if E(x).
+Power may be fractional.
+
+B<NOTE> Experimental. Not present in Statistics::Descriptive::Full.
+
+=cut
+
+sub std_abs_moment {
+    my ($self, $power, $offset) = @_;
+
+    return  $self->abs_moment($power, $offset)
+                /
+            ($self->abs_moment(2, $offset) ** ($power/2));
+};
+
 =head2 mode
 
 Mode of a distribution is the most common value for a discrete distribution,
@@ -942,6 +1008,7 @@ sub TO_JSON {
 		base => $self->{base},
 		linear_width => $self->{linear_width},
 		linear_thresh => $self->{linear_thresh} * ($self->{base}+9)/10,
+		only_linear => $self->{only_linear},
 		data => $self->get_data_hash,
 	};
 };
@@ -1228,6 +1295,8 @@ or this function dies.
 
 =item * E(n) - std_moment - standard moment of n-th power (requires argument),
 
+=item * A(n) - abs_moment - absolute moment of n-th power (requires argument).
+
 =back
 
 For example,
@@ -1259,6 +1328,7 @@ my %format = (
     P => 'cdf?',
     e => 'central_moment?',
     E => 'std_moment?',
+    A => 'abs_moment?',
 );
 
 my %printf = (
@@ -1273,7 +1343,6 @@ $re_format = qr((?:$re_format));
 sub format {
 	my ($self, $format, @extra) = @_;
 
-
 	# FIXME this accepts %m(5), then dies - UGLY
     # TODO rewrite this as a giant sprintf... one day...
 	$format =~ s <%([0-9.\-+ #]*)($re_format)(?:\(($re_num)?\)){0,1}>
@@ -1345,11 +1414,13 @@ sub _memoize_method {
 	}
 	: sub {
 		my $self = shift;
-		my $arg = shift;
-		$arg = '' unless defined $arg;
+		my $arg = do {
+			no warnings 'uninitialized'; ## no critic
+			join ':', @_;
+		};
 
 		if (!exists $self->{cache}{"$name:$arg"}) {
-			$self->{cache}{"$name:$arg"} = $orig_code->($self, $arg);
+			$self->{cache}{"$name:$arg"} = $orig_code->($self, @_);
 		};
 		return $self->{cache}{"$name:$arg"};
 	};
@@ -1366,7 +1437,8 @@ foreach ( qw(sum sumsq mean min max mode) ) {
 };
 
 # Memoize methods with 1 argument
-foreach (qw(quantile central_moment std_moment standard_deviation variance)) {
+foreach (qw(quantile central_moment std_moment abs_moment standard_deviation
+	variance)) {
 	__PACKAGE__->_memoize_method($_, 1);
 };
 
@@ -1374,6 +1446,7 @@ foreach (qw(quantile central_moment std_moment standard_deviation variance)) {
 {
 	no warnings 'once'; ## no critic
 	*std_dev = \&standard_deviation;
+	*stdev = \&standard_deviation;
 };
 
 # Get number of values below $x
